@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw fretboard chord diagrams
 
-our $VERSION = '0.0701';
+our $VERSION = '0.0702';
 
 use Moo;
 use strictures 2;
@@ -152,7 +152,7 @@ sub draw {
     }
 
     # Draw the vertical string lines
-    for my $string (0 .. $self->strings - 1) {
+    for my $string ( 0 .. $self->strings - 1 ) {
         $i->line(
             color => $BLUE,
             x1    => $SPACE + $string * $SPACE,
@@ -285,7 +285,7 @@ sub _draw_horiz {
     }
 
     # Draw the vertical string lines
-    for my $string (0 .. $self->strings - 1) {
+    for my $string ( 0 .. $self->strings - 1 ) {
         $i->line(
             color => $BLUE,
             y1    => $SPACE + $string * $SPACE,
@@ -418,7 +418,7 @@ Music::FretboardDiagram - Draw fretboard chord diagrams
 
 =head1 VERSION
 
-version 0.0701
+version 0.0702
 
 =head1 SYNOPSIS
 
@@ -456,7 +456,12 @@ version 0.0701
 A C<Music::FretboardDiagram> object draws fretboard chord diagrams including
 neck position and chord name annotations for guitar, ukulele, banjo, etc.
 
-=for html <br><img src="https://raw.githubusercontent.com/ology/Music-FretboardDiagram/master/chord-diagram.png"><br>
+Below are examples of a vertical guitar diagram and a horizontal ukulele diagram:
+
+=for html <br>
+<img src="https://raw.githubusercontent.com/ology/Music-FretboardDiagram/master/chord-diagram.png">
+<img src="https://raw.githubusercontent.com/ology/Music-FretboardDiagram/master/ukulele.png">
+<br>
 
 =head1 ATTRIBUTES
 
@@ -501,7 +506,8 @@ Examples:
   $position = $dia->position;
 
 The neck position of a chord to be diagrammed.  This number is rendered to the
-left of the first fret.
+left of the first fret in vertical mode.  When drawing horizontally, the
+position is rendered above the first fret.
 
 Default: 1
 
@@ -581,7 +587,7 @@ A hashref of the string notes.  This is a computed attribute.
   $dia->showname($chord_name);
   $showname = $dia->showname;
 
-Show the chord name or not.
+Show a chord name or not.
 
 Sometimes the computed chord name is not that accurate.  In those cases set the
 B<showname> to a string of your choosing before drawing.
